/*
*******************************************************************************
**
**  This device driver was created by Applilet for the 78K0S/KB1+, 78K0S/KA1+,
**  78K0S/KY1+ 8-Bit Single-Chip Microcontrollers.
**
**  Copyright(C) NEC Electronics Corporation 2002-2006
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	main.c
**  Abstract :	This file implements main function.
**  APIlib :	NEC78K0SKX1+.lib V1.50 [23 Feb. 2006]
**
**  Device :	uPD78F9222
**
**  Compiler :	NEC/CC78K0
**
*******************************************************************************
*/
/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "system.h"
#include "int.h"
#include "port.h"
#include "timer.h"
#include "watchdogtimer.h"
/*
*******************************************************************************
**  MacroDefine
*******************************************************************************
*/
/*
**---------------------------------------------------------------------------
**
**  Abstract:
**	This function implements main function.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**---------------------------------------------------------------------------
*/
unsigned char	mune_red_count;
unsigned char	mune_blue_count;
unsigned char	mune_green_count;
unsigned char	ude_right_count;
unsigned char	ude_left_count;
unsigned char	belt_count;

unsigned char	mune_red_on;
unsigned char	mune_red_off;
unsigned char	mune_blue_on;
unsigned char	mune_blue_off;
unsigned char	mune_green_on;
unsigned char	mune_green_off;
unsigned char	ude_right_on;
unsigned char	ude_right_off;
unsigned char	ude_left_on;
unsigned char	ude_left_off;
unsigned char	belt_on;
unsigned char	belt_off;

unsigned char	int_count;

unsigned char	led_data;
unsigned char	led_change_count;
unsigned char	led_pattern;


const unsigned char pattern1[32]=
		{0x00,0x00,0x10,0x10,0x20,0x20,0x30,0x40,0x50,0x60,
		 0x70,0x60,0x50,0x40,0x30,0x20,0x10,0x10,0x20,0x30,
		 0x40,0x50,0x60,0x70,0x60,0x50,0x40,0x30,0x20,0x20,
		 0x10,0x10};
const unsigned char pattern2[32]=
		{0x70,0x50,0x30,0x10,0x00,0x10,0x30,0x50,0x70,0x50,
		 0x30,0x10,0x00,0x10,0x30,0x50,0x70,0x50,0x30,0x10,
		 0x00,0x10,0x30,0x50,0x70,0x50,0x30,0x10,0x00,0x10,
		 0x30,0x50};
const unsigned char pattern3[32]=
		{0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x20,0x20,
		 0x20,0x30,0x40,0x50,0x60,0x70,0x70,0x60,0x50,0x40,
		 0x30,0x20,0x20,0x20,0x10,0x10,0x10,0x10,0x00,0x00,
		 0x00,0x00};
const unsigned char pattern4[32]=
		{0x50,0x40,0x30,0x20,0x10,0x00,0x10,0x20,0x30,0x40,
		 0x50,0x60,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
		 0x60,0x50,0x40,0x30,0x20,0x10,0x00,0x10,0x20,0x30,
		 0x40,0x50};
const unsigned char pattern5[32]=
		{0x70,0x70,0x60,0x60,0x60,0x50,0x50,0x40,0x40,0x30,
		 0x30,0x20,0x20,0x10,0x10,0x00,0x00,0x10,0x10,0x20,
		 0x20,0x30,0x30,0x40,0x40,0x50,0x50,0x60,0x60,0x60,
		 0x70,0x70};
const unsigned char pattern6[32]=
		{0x70,0x70,0x40,0x40,0x10,0x10,0x00,0x00,0x70,0x70,
		 0x40,0x40,0x10,0x10,0x00,0x00,0x70,0x70,0x40,0x40,
		 0x10,0x10,0x00,0x00,0x70,0x70,0x40,0x40,0x10,0x10,
		 0x00,0x00};

const unsigned char pattern7[32]=
		{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		 0x00,0x00};


void	led_init_set(void)
{
	mune_red_on=0;
	mune_blue_on=0;
	mune_green_on=0;
	ude_right_on=0;
	ude_left_on=0;
	belt_on=0;
	
	mune_red_off=0x70;
	mune_blue_off=0x70;
	mune_green_off=0x70;
	ude_right_off=0x70;
	ude_left_off=0x70;
	belt_off=0x70;
}

void	led_count_set(void)
{
	mune_red_count=mune_red_on;
	mune_blue_count=mune_blue_on;
	mune_green_count=mune_green_on;
	ude_right_count=ude_right_on;
	ude_left_count=ude_left_on;
	belt_count=belt_on;
}
void	led_disp(void)
{
	P4=(P4|0x3f)&(led_data&0x3f);
}

void	main( void )
{
	/* TODO. add user code */


	led_init_set();
	led_count_set();
	led_data=0;
	int_count=254;
	led_change_count=0;
	led_pattern=0;

	TM00_Start();

	while(1){
		led_disp();




	}
}
